==> connector-service-1.0.0-20190820.034103-46-sources.jar: com/bizvane/connectorservice/entity/common/OrderRefundRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;

import java.math.BigDecimal;
import java.util.Date;

/**
 * @author liuying
 * @date 2018/8/17
 * @description
 */

public class OrderRefundRequestVO extends BaseModel{

    /**
     * 订单编号
     */
    private String orderNo;

    /**
     * 会员卡号(线下会员卡号)
     */
    private String offlineCardNo;

    /**
     * 会员id(线下会员id)
     */
    private String erpId;

    /**
     * 审核时间(格式：yyyy-MM-dd HH:mm:ss)
     */
    private Date refundDate;

    /**
     * 退款单号
     */
    private String refundNo;

    /**
     * 退款金额
     */
    private BigDecimal refundMoney;

    /**
     * 退款备注
     */
    private String redundRemark;

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getOfflineCardNo() {
        return offlineCardNo;
    }

    public void setOfflineCardNo(String offlineCardNo) {
        this.offlineCardNo = offlineCardNo;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public Date getRefundDate() {
        return refundDate;
    }

    public void setRefundDate(Date refundDate) {
        this.refundDate = refundDate;
    }

    public String getRefundNo() {
        return refundNo;
    }

    public void setRefundNo(String refundNo) {
        this.refundNo = refundNo;
    }

    public BigDecimal getRefundMoney() {
        return refundMoney;
    }

    public void setRefundMoney(BigDecimal refundMoney) {
        this.refundMoney = refundMoney;
    }

    public String getRedundRemark() {
        return redundRemark;
    }

    public void setRedundRemark(String redundRemark) {
        this.redundRemark = redundRemark;
    }
}

==> connector-service-1.0.0-20200320.083306-161-sources.jar: com/bizvane/connectorservice/entity/common/OrderRefundRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * @author liuying
 * @date 2018/8/17
 * @description
 */

public class OrderRefundRequestVO extends BaseModel{

    /**
     * 订单编号
     */
    private String orderNo;

    /**
     * 会员卡号(线下会员卡号)
     */
    private String offlineCardNo;

    /**
     * 会员id(线下会员id)
     */
    private String erpId;

    /**
     * 审核时间(格式：yyyy-MM-dd HH:mm:ss)
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty(
            value = "退单审核时间",
            name = "refundDate",
            required = true,
            example = "2019-12-13 11:28:12"
    )
    private Date refundDate;

    /**
     * 退款单号
     */
    private String refundNo;

    /**
     * 退款金额
     */
    private BigDecimal refundMoney;

    /**
     * 退款备注
     */
    private String redundRemark;

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getOfflineCardNo() {
        return offlineCardNo;
    }

    public void setOfflineCardNo(String offlineCardNo) {
        this.offlineCardNo = offlineCardNo;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public Date getRefundDate() {
        return refundDate;
    }

    public void setRefundDate(Date refundDate) {
        this.refundDate = refundDate;
    }

    public String getRefundNo() {
        return refundNo;
    }

    public void setRefundNo(String refundNo) {
        this.refundNo = refundNo;
    }

    public BigDecimal getRefundMoney() {
        return refundMoney;
    }

    public void setRefundMoney(BigDecimal refundMoney) {
        this.refundMoney = refundMoney;
    }

    public String getRedundRemark() {
        return redundRemark;
    }

    public void setRedundRemark(String redundRemark) {
        this.redundRemark = redundRemark;
    }
}
